@@ -39,7 +39,7 @@ except ImportError:
 
 
 # Initialize the gtk thread engine
-#gtk.gdk.threads_init()
+#gobject.threads_init()
 
 from rednotebook.util import utils
 import rednotebook.util.unicode
@@ -60,6 +60,7 @@ from rednotebook import undo
 from rednotebook.gui.exportAssistant import ExportAssistant
 from rednotebook.gui import categories
 from rednotebook.gui import t2t_highlight
+from rednotebook.gui import browser
 
 
 class MainWindow(object):
@@ -123,7 +124,17 @@ class MainWindow(object):
 		
 		self.editPane = self.builder.get_object('editPane')
 		
-		self.html_editor = HtmlEditor()
+		# Only add the config variable if webkit is available
+		#TODO: Change to 1 when tested
+		use_webkit = browser.webkit and self.redNotebook.config.read('useWebkit', 0)
+		
+		logging.info('Using webkit: %s' % use_webkit)
+		
+		if use_webkit:
+			self.html_editor = browser.HtmlView()
+		else:
+			self.html_editor = HtmlEditor()
+			
 		self.text_vbox = self.builder.get_object('text_vbox')
 		self.text_vbox.pack_start(self.html_editor)
 		self.html_editor.hide()
@@ -358,6 +369,7 @@ class MainWindow(object):
 			text_scrolledwindow.show()
 			self.html_editor.hide()
 			self.preview_button.set_stock_id('gtk-media-play')
+			### Translators: Verb
 			self.preview_button.set_label(_('Preview'))
 			
 			self.preview_mode = False
@@ -374,7 +386,7 @@ class MainWindow(object):
 			self.preview_button.set_stock_id('gtk-edit')
 			#self.preview_button.set_label(' '*3 + 'Edit' + ' '*4)
 			self.preview_button.set_label(_('Edit'))
-		
+			
 			self.preview_mode = True
 			
 		template_button.set_sensitive(not self.preview_mode)
@@ -485,6 +497,7 @@ class MainWindow(object):
 		elif dir_not_found:
 			default_dir = self.redNotebook.dirs.defaultDataDir
 			self.redNotebook.open_journal(default_dir, load_files=True)
+			### Translators: The default journal is located at $HOME/.rednotebook/data
 			self.redNotebook.showMessage(_('The default journal has been opened'))
 			
 	def show_save_error_dialog(self, exitImminent):
@@ -626,16 +639,21 @@ class MainWindow(object):
 			self.dayTextField.apply_format(format, markup)
 			
 		
-		def get_action(format):
+		def get_action(format, translation):
 			return (format, getattr(gtk, 'STOCK_' + format.upper()), \
-				'_' + tmpl(format), \
+				### Translators: The Control (Ctrl) key
+				translation + ' (%s+%s)' % (_('Ctrl'), format[0]), \
 				'<Control>' + format[0], None, \
 				apply_format,
 				)
 		# Create actions
 		strike_action = ('Stricken', gtk.STOCK_STRIKETHROUGH, \
-				'Stricken', None, None, apply_format,)
-		actions = map(get_action, ['Bold', 'Italic', 'Underline']) + [strike_action]
+				_('Stricken'), None, None, apply_format,)
+		actions = [get_action(format, trans) for format, trans in \
+					(('Bold', _('Bold')), \
+					('Italic', _('Italic')), \
+					('Underline', _('Underline')))] \
+					+ [strike_action]
 		actiongroup.add_actions(actions)
 
 		# Add the actiongroup to the uimanager
@@ -649,6 +667,7 @@ class MainWindow(object):
 		
 		#single_menu_toolbutton = SingleMenuToolButton(menu, 'Insert ')
 		self.format_toolbutton = gtk.MenuToolButton(gtk.STOCK_BOLD)
+		### Translators: noun
 		self.format_toolbutton.set_label(_('Format'))
 		tip = _('Format the selected text or category entry')
 		self.format_toolbutton.set_tooltip_text(tip)
@@ -722,6 +741,7 @@ class MainWindow(object):
 			('File', gtk.STOCK_FILE, _('File'), None, \
 				_('Insert a link to a file'), \
 				self.on_insert_file_menu_item_activate),
+			### Translators: Noun
 			('Link', gtk.STOCK_JUMP_TO, _('_Link') + tmpl('L'), '<Control>L', \
 				_('Insert a link to a website'), \
 				self.on_insert_link_menu_item_activate),
@@ -1290,7 +1310,7 @@ class SearchTreeView(object):
 		if self.searchType == 0:
 			# let the search function highlight found strings in the page
 			if self.mainWindow.preview_mode:
-				self.mainWindow.html_editor._textview.highlight(self.searched_text)
+				self.mainWindow.html_editor.highlight(self.searched_text)
 			else:
 				self.mainWindow.dayTextField.highlight(self.searched_text)
 		
@@ -1365,7 +1385,10 @@ class DayTextField(object):
 		variants = set([text, text.capitalize(), text.lower(), text.upper()])
 		
 		for search_text in variants:
-			iter_tuple = iter_start.forward_search(search_text, gtk.TEXT_SEARCH_VISIBLE_ONLY)
+			iter_tuple = iter_start.forward_search(search_text, \
+								gtk.TEXT_SEARCH_VISIBLE_ONLY \
+								#| gtk.SEARCH_CASE_INSENSITIVE # non-existent
+								)
 			
 			# When we find one variant, highlight it and quit
 			if iter_tuple:
