@@ -26,9 +26,12 @@ import operator
 import collections
 import time
 from optparse import OptionParser, OptionValueError
+import gettext
 
 
-	
+# register the gettext function for the whole interpreter as "_"
+import __builtin__
+__builtin__._ = gettext.gettext
 
 
 if hasattr(sys, "frozen"):
@@ -166,13 +169,6 @@ except ImportError, err:
 for module in modules:
     module.bindtextdomain(GETTEXT_DOMAIN, LOCALE_PATH)
     module.textdomain(GETTEXT_DOMAIN)
-    
-
-
-
-# register the gettext function for the whole interpreter as "_"
-import __builtin__
-__builtin__._ = gettext.gettext
 
 ## ------------------- end Enable i18n -------------------------------
 
@@ -194,10 +190,17 @@ try:
 	#logging.disable(logging.ERROR)
 	#logging.disable(logging.WARNING)
 	#logging.disable(logging.CRITICAL)
-	gtk.gdk.threads_init()
 	#gtk.gdk.threads_enter()
 	
 	import gobject
+	# Some notes on threads_init:
+	# only gtk.gdk.threads_init(): pdf export works, but gui hangs afterwards
+	# only gobject.threads_init(): pdf export works, gui works
+	# both: pdf export stopped once while loading, second time worked
+	#       only the first export seems to be not working
+	
+	gobject.threads_init() # only initializes threading in the glib/gobject module
+	#gtk.gdk.threads_init() # also initializes the gdk threads
 except (ImportError, AssertionError):
 	logging.error('gtk not found. Please install PyGTK (python-gtk2)')
 	sys.exit(1)
@@ -414,7 +417,7 @@ class RedNotebook:
 						month.edited = False
 					except OSError, err:
 						self.frame.show_save_error_dialog(exitImminent)
-						return True	
+						return True
 					except IOError, err:
 						self.frame.show_save_error_dialog(exitImminent)
 						return True	
